/* DRAW.I Draws lines in graphics mode */

/* hdraw draws horizontal lines along y between x1 and x2 */
void hdraw (int x1, int x2, int y, int color)
{
int	x;

  if (x1 > x2) {              /* sort x's into left-to-right order */
    x = x1; x1 = x2; x2 = x;
  }
  for (x = x1; x <= x2; x++)
    plot (x, y, color);
} /* -------------------------- */

/* vdraw draws vertical line along x between y1 and y2 */
void vdraw (int y1, int y2, int x, int color)
{
int	y;

  if (y1 > y2) {              /* sort y's into top-to-bottom order */
    y = y1; y1 = y2; y2 = y;
  }
  for (y = y1; y <= y2; y++)
    plot (x, y, color);
} /* -------------------------- */

/* draw() does lines on the diagonal */
void draw (int x1, int y1, int x2, int y2, int color)
{
double	xstep, ystep, xcum = 0.0, ycum = 0.0;
int	dx, dy;                                          /* deltas */
register x, y;

  dx = x2 - x1;
  dy = y2 - y1;
  if (abs (dx) >= abs (dy)) {                 /* plot along x axis */
    ystep = (double) dy / dx;       /* movement along y axis per x */
    if (dy < 0) {                         /* y travels to the left */
      if (ystep > 0)
        ystep *= -1;           /* adjust for wrong sign from -y/-x */
    } else                               /* y travels to the right */
      if (ystep < 0)
        ystep *= -1;                            /* adjust as above */
    dx /= abs (dx);                                 /* x increment */
    for (x = x1, y = y1; x != x2; x += dx) {
      plot (x, y, color);
      ycum += ystep;                    /* cum motion along y axis */
      y = y1 + ycum;                                     /* next y */
    }
  } else {
    xstep = (double) dx / dy;       /* movement along x axis per y */
    if (dx < 0) {
      if (xstep > 0)
        xstep *= -1;
    } else
      if (xstep < 0)
        xstep *= -1;
    dy /= abs (dy);                                 /* y increment */
    for (y = y1, x = x1; y != y2; y += dy) {
      plot (x, y, color);
      xcum += xstep;                    /* cum motion along x axis */
      x = x1 + xcum;                                     /* next x */
    }
  }
} /* -------------------------- */
