/* VID.C Demos video functions */

/* TURBO C INCLUDES */
#include <stdio.h>
#include <bios.h>
#include <dos.h>

/* USER-WRITTEN INCLUDES */
#include <color.h>
#include <video.i>
#include <draw.i>

/* LOCAL FUNCTION PROTOTYPES */
int vidIdent (int *vmode);
void wait (void);
void stairsteps (void);
int isEGA (void);
void label (void);
void bigX (int adap, int vmode);
void hourglass (int adap, int vmode);

/* GLOBALS */
enum vidTypes {mda, cga, ega, compaq, other};

main()
{
int adaptor, mode, cols;

  cls();
  adaptor = vidIdent(&mode);
  if (adaptor != other) {
    stairsteps();
    bigX(adaptor, mode);
    hourglass(adaptor, mode);
    label();
    gotoxy(36, 12, 0);
    puts("All done!");
  }
} /* ------------------------- */

int vidIdent (int *vidmode)
{
int flag, adap, width;

  label();
  puts("\n\nDISPLAY INFORMATION:");
  *vidmode = videomode(&width);
  flag = (biosequip() & 0x18) >> 4;
  if (isEGA()) {
    adap = ega;
    puts("\n\n Enhanced Graphis Adaptor");
  } else
    switch (flag) {
      case 0: if (*vidmode == 2) {
                adap = compaq;
                puts("\n\n Compaq Adaptor");
              } else {
                adap = cga;
                puts("\n\n Color Graphics Adaptor");
              }
              break;
      case 3: adap = mda;
              puts("\n\n Monochrome Display Adaptor");
              break;
      default: adap = other;
              puts("\n\n Adaptor not usable in this demo. Sorry.");
  } /* end of switch */
  printf("\n Text screen size is %d columns x 25 rows\n", width);
  if ((*vidmode < 4) || (*vidmode == 7))
    puts("\n Text mode currently active.");
  else
    puts("\n Graphics mode currently active.");
  wait();
  return(adap);
} /* ------------------------- */

int isEGA (void)
{
  return (peekb (0x40, 0x87));
} /* ------------------------- */

void wait (void)
{
int tab, width;

  videomode(&width);
  tab = (width - 33) / 2;
  gotoxy (tab, 24, 0);
  wrtstr("Press any key to continue demo...:", WHITE, 0);
  getch();
  cls();
} /* ------------------------- */

void label (void)
{
  gotoxy(30, 0, 0);
  wrtstra("Video demonstration:", chattr(YELLOW, BLUE), 0);
} /* ------------------------- */

void stairsteps (void)
{
int color = 1;

  label();
  gotoxy(31,  2, 0); wrtstr("Cursor positioning", LIGHTGRAY, 0);
  gotoxy(10,  4, 0); wrtstr("Stair", color++, 0);
  gotoxy(20, 10, 0); wrtstr("steps", color++, 0);
  gotoxy(30, 16, 0); wrtstr("going", color++, 0);
  gotoxy(40, 22, 0); wrtstr("down",  color++, 0);
  gotoxy(50, 16, 0); wrtstr("and",   color++, 0);
  gotoxy(60, 10, 0); wrtstr("back",  color++, 0);
  gotoxy(70,  4, 0); wrtstr("up",    color++, 0);
  wait();
} /* ------------------------- */

void bigX (int vidAdap, int vmode)
{
int x1 =  0, x2 = 639;
int y1 = 15, y2;

  if ((vidAdap == mda) || (vidAdap == other))
    return;

  if (vidAdap == ega) {
    y2 = 349 - 15;
    setmode (0x0F);
  } else {
    y2 = 199 - 15;
    setmode (0x06);
  }
  label();
  hdraw(x1, x2, y1, 1);
  hdraw(x1, x2, y2, 1);
  vdraw(y1, y2, x1, 1);
  vdraw(y1, y2, x2, 1);
  draw (x1, y1, x2, y2, 1);
  draw (x1, y2, x2, y1, 1);
  wait();
  setmode(vmode);
} /* ------------------------- */

void hourglass (int vidAdap, int vmode)
{
int y, x1 = 60, x2 = 260, pixval = 1;

  if ((vidAdap == mda) || (vidAdap == other))
    return;

  setmode(4);
  gotoxy(8, 0, 0);
  puts("320 x 200 color graphics");
  palette(0);
  for(y = 50; y < 151; y++) {
    hdraw(x1, x2, y, pixval);
    x1 += 2; x2 -= 2;
    if(y == 82) pixval = 2;
    if (y == 117) pixval = 3;
  }
  wait();
  setmode(vmode);
  } /* ------------------------- */
